@@ -31,6 +31,8 @@ import sys
 from fnmatch import fnmatch
 from logging import getLogger
 from time import sleep
+import math
+from xml.dom.minidom import parseString
 
 try:
     from functools import total_ordering
@@ -42,7 +44,7 @@ from copy import deepcopy
 from six import string_types
 from six.moves import urllib
 from requests import Response
-from clint.textui import progress
+from tqdm import tqdm
 from requests.exceptions import HTTPError
 
 from internetarchive.utils import IdentifierListAsItems, get_md5, chunk_generator, \
@@ -216,6 +218,26 @@ class Item(BaseItem):
             item_metadata = self.session.get_metadata(self.identifier, **kwargs)
         self.load(item_metadata)
 
+    def identifier_available(self):
+        """Check if the item identifier is available for creating a
+        new item.
+
+        :rtype: bool
+        :return: `True` if identifier is available, or `False` if it is
+                 not available.
+        """
+        url = '{}//{}/services/check_identifier.php'.format(self.session.protocol,
+                                                            self.session.host)
+        params = dict(identifier=self.identifier)
+        r = self.session.get(url, params=params)
+        p = parseString(r.text)
+        result = p.getElementsByTagName('result')[0]
+        available = result.attributes['code'].value
+        if available == 'not_available':
+            return False
+        else:
+            return True
+
     def get_task_summary(self, params=None, request_kwargs=None):
         """Get a summary of the item's pending tasks.
 
@@ -252,6 +274,7 @@ class Item(BaseItem):
 
         :rtype: List[CatalogTask]
         """
+        params = dict() if not params else params
         params.update(dict(catalog=1, history=1))
         return self.session.get_tasks(self.identifier, params, request_kwargs)
 
@@ -406,6 +429,7 @@ class Item(BaseItem):
                  on_the_fly=None,
                  return_responses=None,
                  no_change_timestamp=None,
+                 ignore_history_dir=None,
                  params=None):
         """Download files from an item.
 
@@ -472,6 +496,10 @@ class Item(BaseItem):
         :param params: (optional) URL parameters to send with
                        download request (e.g. `cnt=0`).
 
+        :type ignore_history_dir: bool
+        :param ignore_history_dir: (optional) Do not download any files from the history
+                                   dir. This param defaults to ``False``.
+
         :rtype: bool
         :returns: True if if all files have been downloaded successfully.
         """
@@ -484,6 +512,7 @@ class Item(BaseItem):
         no_directory = False if no_directory is None else no_directory
         return_responses = False if not return_responses else True
         no_change_timestamp = False if not no_change_timestamp else no_change_timestamp
+        ignore_history_dir = False if ignore_history_dir is None else ignore_history_dir
         params = None if not params else params
 
         if not dry_run:
@@ -536,6 +565,9 @@ class Item(BaseItem):
         responses = list()
 
         for f in files:
+            if ignore_history_dir is True:
+                if f.name.startswith('history/'):
+                    continue
             if no_directory:
                 path = f.name
             else:
@@ -720,7 +752,7 @@ class Item(BaseItem):
         secret_key = self.session.secret_key if secret_key is None else secret_key
         queue_derive = True if queue_derive is None else queue_derive
         verbose = False if verbose is None else verbose
-        verify = True if verify is None else verify
+        verify = False if not verify else verify
         delete = False if delete is None else delete
         # Set checksum after delete.
         checksum = True if delete else checksum
@@ -794,12 +826,12 @@ class Item(BaseItem):
                         raise Exception
 
                     chunk_size = 1048576
-                    expected_size = size / chunk_size + 1
+                    expected_size = math.ceil(size / chunk_size)
                     chunks = chunk_generator(body, chunk_size)
-                    progress_generator = progress.bar(
-                        chunks,
-                        expected_size=expected_size,
-                        label=' uploading {f}: '.format(f=key))
+                    progress_generator = tqdm(chunks,
+                                              desc=' uploading {}'.format(key),
+                                              dynamic_ncols=True,
+                                              total=expected_size)
                     data = IterableToFileAdapter(progress_generator, size)
                 except:
                     print(' uploading {f}'.format(f=key))
@@ -824,10 +856,10 @@ class Item(BaseItem):
             return prepared_request
         else:
             try:
-                error_msg = ('s3 is overloaded, sleeping for '
-                             '{0} seconds and retrying. '
-                             '{1} retries left.'.format(retries_sleep, retries))
                 while True:
+                    error_msg = ('s3 is overloaded, sleeping for '
+                                 '{0} seconds and retrying. '
+                                 '{1} retries left.'.format(retries_sleep, retries))
                     if retries > 0:
                         if self.session.s3_is_overloaded(access_key):
                             sleep(retries_sleep)
